==> vips7.8_7.8.14.orig.tar.gz: vips-7.8.14/doc/html/appguide/images.pl <==
# LaTeX2HTML 99.2beta8 (1.43)
# Associate images original text with physical files.


$key = q/b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$b^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim56#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="540" HEIGHT="222" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}int
im_Lab2disp( IMAGE *in, IMAGE...
...t, disp ) )
return( -1 );return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim51#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="527" HEIGHT="683" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Add another image to the accumu...
...n( sum1( in[0], in + 1, nin - 1, out ) );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim48#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="619" HEIGHT="489" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim57#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="348" HEIGHT="203" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}int
threshold_at_mean( IMAGE *in, ...
...t, mean ) )
return( -1 );return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/L^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$L^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim46#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="533" HEIGHT="547" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/^{-1};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="20" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$^{-1}$">|; 

$key = q/L^{*}a^{*}b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="54" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$L^{*}a^{*}b^{*}$">|; 

$key = q/includegraphics[width=6in]{figsslasharch.eps};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="681" HEIGHT="428" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics[width=6in]{figs/arch.eps}">|; 

$key = q/a^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$a^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim38#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="526" HEIGHT="550" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}typedef struct {
/* Fields from i...
...ed by VIPS for
... housekeeping.
} IMAGE;\end{verbatim}\end{quote}\end{figure}">|; 

1;

==> vips_7.10.10.orig.tar.gz: vips-7.10.10/doc/html/appguide/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/{figure}quote{preform{<verbatim_mark>verbatim38#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="591" HEIGHT="529" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}typedef struct {
/* Fields from i...
... by VIPS for
... housekeeping.
} IMAGE;\end{verbatim}
\end{quote}
\end{figure}">|; 

$key = q/^{-1};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$^{-1}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim46#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="607" HEIGHT="548" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/L^{*}a^{*}b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="52" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$L^{*}a^{*}b^{*}$">|; 

$key = q/a^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$a^{*}$">|; 

$key = q/b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$b^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim57#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="396" HEIGHT="203" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}int
threshold_at_mean( IMAGE *in, ...
... mean ) )
return( -1 );return( 0 );
}\end{verbatim}
\end{quote}
\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim56#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="615" HEIGHT="222" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}int
im_Lab2disp( IMAGE *in, IMAGE...
... disp ) )
return( -1 );return( 0 );
}\end{verbatim}
\end{quote}
\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim48#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="706" HEIGHT="490" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/includegraphics[width=6in]{figsslasharch.eps};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="681" HEIGHT="428" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics[width=6in]{figs/arch.eps}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim51#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="601" HEIGHT="681" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Add another image to the accumu...
... sum1( in[0], in + 1, nin - 1, out ) );
}\end{verbatim}
\end{quote}
\end{figure}">|; 

$key = q/L^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$L^{*}$">|; 

1;
